package com.ruoyi.frequency.recommend.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.frequency.recommend.entity.Recommend;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 推荐Mapper接口
 *
 * @author liwenlong
 * @date 2023-10-20
 */
public interface RecommendMapper  extends BaseMapper<Recommend>
{
    /**
     * 查询推荐
     *
     * @param id 推荐主键
     * @return 推荐
     */
    public Recommend selectRecommendById(Long id);

    /**
     * 查询推荐列表
     *
     * @param recommend 推荐
     * @return 推荐集合
     */
    public List<Recommend> selectRecommendList(Recommend recommend);

    /**
     * 新增推荐
     *
     * @param recommend 推荐
     * @return 结果
     */
    public int insertRecommend(Recommend recommend);

    /**
     * 修改推荐
     *
     * @param recommend 推荐
     * @return 结果
     */
    public int updateRecommend(Recommend recommend);

    /**
     * 删除推荐
     *
     * @param id 推荐主键
     * @return 结果
     */
    public int deleteRecommendById(Long id);

    /**
     * 批量删除推荐
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecommendByIds(Long[] ids);

    void topping(@Param("req") Recommend recommend);
}
